package com.bjlt.spider.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.bjlt.spider.bean.AirSourceLine;
import com.bjlt.spider.bean.ExchangeRateInstance;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.dao.IAirSourceLineDao;
import com.bjlt.spider.dao.ScExchangeRateDao;
import com.bjlt.spider.datasources.DataSourceNames;
import com.bjlt.spider.datasources.annotation.DataSource;
import com.bjlt.spider.entity.ScExchangeRate;
import com.bjlt.spider.entity.ScPolicy;
import com.bjlt.spider.entity.SourceEnum;
import com.bjlt.spider.entity.TriptoCustomAddprice;
import com.bjlt.spider.service.IAirSoureLineService;
import com.bjlt.spider.service.ScPolicyService;
import com.bjlt.spider.service.SeAirsourceLineService;
import com.bjlt.spider.thread.SaveErrorLineThread;
import com.bjlt.spider.thread.SaveNewAirLineThread;
import com.bjlt.spider.thread.SendCacheThread;
import com.bjlt.spider.utils.request.RequestUtil;
import com.bjlt.spider.utils.request.ToolUtils;
import com.luyn.date.DatePattren;
import com.luyn.date.DateUtil;
import com.luyn.http.okhttp.OkHttpDownLoader;
import com.luyn.log.SysLogger;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.net.SocketTimeoutException;
import java.util.*;
import java.util.concurrent.ExecutorService;


@Service
@Slf4j
public class AirSoureLineServiceImpl implements IAirSoureLineService {

    private static final SysLogger logger = SysLogger.getSysLogger(AirSoureLineServiceImpl.class);

    @Autowired
    IAirSourceLineDao airSourceLineDao;

    @Autowired
    Config config;

    @Autowired
    ScExchangeRateDao scExchangeRateDao;

    @Autowired
    ScPolicyService scPolicyService;

    @Autowired
    TriptoCustomAddpriceServiceImpl triptoCustomAddpriceService;

    @Autowired
    ExecutorService executorService;


    @Autowired
    SeAirsourceLineService seAirsourceLineService;


    @Override
    public List<AirSourceLine> selectAirSourceLine() {
        List<AirSourceLine> airSourceLines = airSourceLineDao.selectAllAirSourceLines();
        List<AirSourceLine> tempAirSourceLines = new ArrayList<>();
        List<String> key = new ArrayList<>();
        for (AirSourceLine airSoureLine : airSourceLines) {
            tempAirSourceLines.add(airSoureLine);
        }
        for (AirSourceLine airSourceLine : airSourceLines) {
            String fromCity = airSourceLine.getFromCity();
            String toCity = airSourceLine.getToCity();
            if (key.contains(toCity + "_" + fromCity)) {
                continue;
            }
            for (AirSourceLine tempSorceLine : tempAirSourceLines) {
                if (tempSorceLine.getToCity().equals(fromCity)
                        && tempSorceLine.getFromCity().equals(toCity)) {
                    tempAirSourceLines.remove(tempSorceLine);
                    key.add(fromCity + "_" + toCity);
                    break;
                }
            }
        }
        return tempAirSourceLines;
    }



    /**
     * 进行业务之间的查询
     *
     * @param searchKey
     */
    @Override
    public void processSearch(String searchKey) {
        String[] split = searchKey.split("[_]");
        String fromStation = split[0];
        String toStation = split[1];
        String fromDate = split[2];
        String currency = split[3];
        Date date = DateUtil.getFormatDate(fromDate, "yyyy-MM-dd");
        //比当前日期早两天则不进行查询
        if (date.before(DateUtil.getBeforeDay(new Date(),-2))) {
            return;
        }
        String retDate = DateUtil.getFormatDate(DateUtil.getBeforeDay(date, -7), "yyyy-MM-dd");


        //查询bigapp
        String bigData = "";
        try{
             bigData = searchData(SourceEnum.AK_BIG_APP.getSourceName(), fromStation, toStation, fromDate, currency, retDate);
            logger.info(SysLogger.builder().logFilePath("searchlog").isCreateFile(true).name("searchlog").message(bigData).build());
            // log.info("big查询结果--->"+bigData);
        }catch (Exception e){
            log.info(e.getMessage());
            return;
        }
        try {
            JSONObject bigDataJSON = JSONObject.parseObject(bigData);
            int status = bigDataJSON.getIntValue("status");
            if (status != 200) {
                //此查询失败 进行失败逻辑
                executorService.submit(new SaveErrorLineThread(fromStation,toStation,fromDate,retDate,1,0));
                ExchangeRateInstance.getInstance().setSearchmoiter(searchKey,1,"查询失败");
                return;
            }
            JSONObject attachment = bigDataJSON.getJSONObject("attachment");
            //去程
            JSONArray fromSegments = attachment.getJSONArray("fromSegments");
            //回程
            JSONArray retSegments = attachment.getJSONArray("retSegments");
            if (ToolUtils.isEmpty(fromSegments)
                    && ToolUtils.isEmpty(retSegments)) {
                //去程和回程都无车次 失败
                ExchangeRateInstance.getInstance().setSearchmoiter(searchKey,1,"去程和回程都无车次 失败");
                executorService.submit(new SaveErrorLineThread(fromStation,toStation,fromDate,retDate,2,0));
                return;
            }

            ExchangeRateInstance.getInstance().setSearchmoiter(searchKey,1,"成功");
            //查询web端
            String webData = "";
            try{
                 webData = searchData(SourceEnum.AK_WEB.getSourceName(), fromStation, toStation, fromDate, currency, retDate);
                logger.info(SysLogger.builder().logFilePath("searchlog").isCreateFile(true).name("searchlog").message(webData).build());
            }catch (Exception e){
                log.info(e.getMessage());
                return;
            }

            JSONObject webDataJSON = JSONObject.parseObject(webData);
            int web_status = webDataJSON.getIntValue("status");
            if (web_status != 200) {
                //此WEB查询失败 进行失败逻辑
                ExchangeRateInstance.getInstance().setSearchmoiter(searchKey,0,"查询失败");
                executorService.submit(new SaveErrorLineThread(fromStation,toStation,fromDate,retDate,1,1));
                return;
            }

            JSONObject web_attachment = webDataJSON.getJSONObject("attachment");
            //去程
            JSONArray web_fromSegments = web_attachment.getJSONArray("fromSegments");
            //回程
            JSONArray web_retSegments = web_attachment.getJSONArray("retSegments");

            if (ToolUtils.isEmpty(web_fromSegments)
                    && ToolUtils.isEmpty(web_retSegments)) {
                //web 去程和回程都无车次 失败
                ExchangeRateInstance.getInstance().setSearchmoiter(searchKey,0,"去程和回程都无车次 失败");
                executorService.submit(new SaveErrorLineThread(fromStation,toStation,fromDate,retDate,2,1));
                return;
            }
            ExchangeRateInstance.getInstance().setSearchmoiter(searchKey,0,"成功");
            //刷新缓存
            executorService.submit(new SendCacheThread(webData));

            //此航班是否可以拉黑
            if(isCanPullTheBlack(fromSegments)&&isCanPullTheBlack(retSegments)){
                seAirsourceLineService.pulltheblack(fromStation,toStation);
                seAirsourceLineService.pulltheblack(toStation,fromStation);
                return;
            }



            //对比去程
            compare(fromSegments, web_fromSegments, false);
            //对比回程
            compare(retSegments, web_retSegments, true);


            //此航线有数据把此航线入DB
            executorService.submit(new SaveNewAirLineThread(fromStation,toStation,currency));



        } catch (Exception e) {
                log.info(e.getMessage());
        }

    }


    /**
     * 判断是否可以拉黑此航线
     * @param fromSegments
     * @return
     */
    private boolean isCanPullTheBlack(JSONArray fromSegments) {
        boolean isCan = true;
        for (int i = 0; i < fromSegments.size(); i++) {
            JSONObject fromSegmentsObject = fromSegments.getJSONObject(i);
            String formCity = fromSegmentsObject.getString("formCity");
            String fromDate = fromSegmentsObject.getString("fromDate");
            String toCity = fromSegmentsObject.getString("toCity");
            String currency = fromSegmentsObject.getString("currency");
            JSONArray airlinePriceInfos = fromSegmentsObject.getJSONArray("routeInfoEntities");
            if(airlinePriceInfos.size()<=1){
                isCan = false;
                break;
            }
        }

        return  isCan;
    }


    /**
     * 对比行程
     *
     * @param fromSegments     手机端
     * @param web_fromSegments web端
     * @param isReturn         是否是回程
     */
    private void compare(JSONArray fromSegments, JSONArray web_fromSegments, boolean isReturn) {
        if (ToolUtils.isEmpty(fromSegments)
                || ToolUtils.isEmpty(web_fromSegments)) {
            return;
        }
        //外层是bigapp端
        for (int i = 0; i < fromSegments.size(); i++) {
            JSONObject fromSegmentsObject = fromSegments.getJSONObject(i);
            String formCity = fromSegmentsObject.getString("formCity");
            String fromDate = fromSegmentsObject.getString("fromDate");
            String toCity = fromSegmentsObject.getString("toCity");
            String currency = fromSegmentsObject.getString("currency");

            JSONArray airlinePriceInfos = fromSegmentsObject.getJSONArray("airlinePriceInfos");
            //获取到最低价格
            JSONObject bigappEcPrice = getPrice(airlinePriceInfos);

            JSONArray routeInfoEntities = fromSegmentsObject.getJSONArray("routeInfoEntities");
            //循环web端
            for (int j = 0; j < web_fromSegments.size(); j++) {
                JSONObject web_fromSegmentsObject = web_fromSegments.getJSONObject(j);
                String web_formCity = web_fromSegmentsObject.getString("formCity");
                String web_fromDate = web_fromSegmentsObject.getString("fromDate");
                String web_toCity = web_fromSegmentsObject.getString("toCity");
                String web_currency = web_fromSegmentsObject.getString("currency");
                //判断行程日期
                if (!formCity.equals(web_formCity) || !toCity.equals(web_toCity) || !fromDate.equals(web_fromDate)) {
                    continue;
                }
                //判断航班号
                JSONArray web_routeInfoEntities = web_fromSegmentsObject.getJSONArray("routeInfoEntities");
                //判断航班号是否都一致
                if (!compareRouteInfo(routeInfoEntities, web_routeInfoEntities)) {
                    continue;
                }
                JSONArray web_airlinePriceInfos = web_fromSegmentsObject.getJSONArray("airlinePriceInfos");
                //获取到最低价格
                JSONObject webEcPrice = getPrice(web_airlinePriceInfos);
                //获取对应的航班号
                String allFlightNumber = getAllFlightNumber(routeInfoEntities);
                //BIG的积分换算
                Double finalRate =  getFinalRate(currency);

                //获取web
                Double webfinalRate = getFinalRate(web_currency);
                if(ToolUtils.isEmpty(finalRate)||ToolUtils.isEmpty(webfinalRate)){
                    logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("not_currency").message(JSONObject.toJSONString(currency)
                    +"__"+formCity+"__"+toCity+"__"+fromDate+"__"+currency).build());
                    return;
                }
                //big的数据
                BigDecimal bigPrice =bigappEcPrice.getBigDecimal("price");
                String  totalPoint =bigappEcPrice.getString("AdultQuotedPoints");
                //剩余座位数
                int maxSeats = bigappEcPrice.getIntValue("maxSeats");
                //web的数据
                BigDecimal web_priice = webEcPrice.getBigDecimal("price");
                BigDecimal bigCNY  = bigPrice.multiply(new BigDecimal(finalRate));

                //积分价格大于2500 并且航班号 大于2个则不要这个数据
                if(routeInfoEntities.size()>=2){
                    continue;
                }


                BigDecimal webCNY  = web_priice.multiply(new BigDecimal(webfinalRate));
                log.info(formCity+"---"+toCity+"---"+fromDate+"---"+allFlightNumber+"---"+bigappEcPrice.toString() + "-----" + webEcPrice.toString());
                log.info(formCity+"---"+toCity+"---"+fromDate+"---"+allFlightNumber+"--big-"+bigCNY + "--web---" + webCNY);
                //此时可以入政策
                if((webCNY.subtract(bigCNY).doubleValue())>=config.getBig_web_price()){
                    //插入政策表
                    try{
                        ScPolicy newscPolicy = new ScPolicy();
                        newscPolicy.setAirSourceGroupId(1);
                        newscPolicy.setCid("QUNA");
                        newscPolicy.setFromCity(formCity);
                        newscPolicy.setToCity(toCity);
                        newscPolicy.setFromDateStart(fromDate);
                        newscPolicy.setFlightNumberLimitType(1);
                        newscPolicy.setFlightNumberLimit(allFlightNumber);
                        List<ScPolicy> scPolicies = scPolicyService.listScPolicy(newscPolicy);
                        if(ToolUtils.isEmpty(scPolicies)){
                            ScPolicy scPolicy = new ScPolicy();
                            scPolicy.setAirSourceGroupId(1);
                            scPolicy.setCid("QUNA");
                            scPolicy.setFromCity(formCity);
                            scPolicy.setToCity(toCity);
                            scPolicy.setFromDateStart(fromDate);
                            scPolicy.setFromDateEnd(fromDate);
                            scPolicy.setFlightNumberLimitType(1);
                            scPolicy.setFlightNumberLimit(allFlightNumber);
                            scPolicy.setOriginalPrice(webCNY);
                            scPolicy.setLowPrice(new BigDecimal(10));
                            scPolicy.setUpPrice(new BigDecimal(99999999));
                            scPolicy.setAdjustType("0");
                            scPolicy.setFinalPrice(new BigDecimal(bigCNY.intValue()+config.getAddPrice()));
                            scPolicy.setFileNo("BIG-loop-insrt积分系统");
                            scPolicy.setAddOrSubtractMoney("0");
                            scPolicy.setAddTime(DateUtil.getFormatDate(new Date(), DatePattren.TIME_FORMAT));
                            scPolicy.setScore(String.valueOf(bigCNY.doubleValue()));
                            scPolicy.setPolicySource("point");
                            scPolicy.setCabinScope("0");
                            scPolicy.setBigScore(totalPoint);
                            scPolicy.setBigSeatCount(maxSeats);
                            logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("add_old_policy").message(JSONObject.toJSONString(scPolicy)).build());
                            scPolicyService.insertSelective(scPolicy);

                        }else{
                            ScPolicy updatescPolicy = scPolicies.get(0);
                            ScPolicy scPolicy = new ScPolicy();
                            scPolicy.setId(updatescPolicy.getId());
                            scPolicy.setAirSourceGroupId(1);
                            scPolicy.setCid("QUNA");
                            scPolicy.setFromCity(formCity);
                            scPolicy.setToCity(toCity);
                            scPolicy.setFromDateStart(fromDate);
                            scPolicy.setFromDateEnd(fromDate);
                            scPolicy.setFlightNumberLimitType(1);
                            scPolicy.setFlightNumberLimit(allFlightNumber);
                            scPolicy.setOriginalPrice(webCNY);
                            scPolicy.setLowPrice(new BigDecimal(10));
                            scPolicy.setUpPrice(new BigDecimal(99999999));
                            scPolicy.setAdjustType("0");
                            scPolicy.setFinalPrice(new BigDecimal(bigCNY.intValue()+config.getAddPrice()));
                            scPolicy.setFileNo("BIG-loop-update积分系统");
                            scPolicy.setAddOrSubtractMoney("0");
                            scPolicy.setAddTime(DateUtil.getFormatDate(new Date(), DatePattren.TIME_FORMAT));
                            scPolicy.setScore(String.valueOf(bigCNY.doubleValue()));
                            scPolicy.setPolicySource("point");
                            scPolicy.setCabinScope("0");
                            scPolicy.setBigScore(totalPoint);
                            scPolicy.setBigSeatCount(maxSeats);
                            logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("add_old_policy").message(JSONObject.toJSONString(scPolicy)).build());
                            scPolicyService.updateByPrimaryKeySelective(scPolicy);
                        }
                    }catch (Exception e){
                        log.info(e.getMessage());
                    }
                   try {
                       String index =formCity +"~"+toCity +"~"+"AKNEW" +"~"+fromDate +"~"+fromDate +"~"+allFlightNumber +"~"+"ltd/lqe/tuniu/meituan/tongcheng/ali" +"~"+1;
                       TriptoCustomAddprice newtriptoCustomAddprice = new TriptoCustomAddprice();
                       newtriptoCustomAddprice.setIndex(index);
                       List<TriptoCustomAddprice> triptoCustomAddprices = triptoCustomAddpriceService.listTriptoCustomAddprice(newtriptoCustomAddprice);
                       if(ToolUtils.isEmpty(triptoCustomAddprices)){
                           //插入新的政策表
                           TriptoCustomAddprice triptoCustomAddprice = TriptoCustomAddprice.builder()
                                   .name("system")
                                   .filename("BIG-loop-insrt积分系统") //文件编号
                                   .platform("ltd/lqe/tuniu/meituan/tongcheng/ali")//
                                   .enable(3)//1 有效 0 无效 3 挂起
                                   .method("AKNEW")
                                   .dptAirport(formCity)
                                   .arrAirport(toCity)
                                   .flyStartday(fromDate)
                                   .flyEndday(fromDate)
                                   .excludeFlyStartday("")
                                   .excludeFlyEndday("")
                                   .flightNoStatus(1)//1，适用 2，排除 3，全部
                                   .flightNo(allFlightNumber)
                                   .isSalePrice(1)//1 固定价格 2 区间价
                                   .salePrice(Double.valueOf(bigCNY.intValue()+config.getAddPrice()))//销售价格
                                   .addPrice(0)//加减钱
                                   .addPricePercent(0.0)//调整百分比
                                   .webrmbPrice(webCNY.doubleValue())//官网人民币总参考价格
                                   .bigrmbPrice(bigCNY.doubleValue())//积分人民币总参考价格
                                   .priceDifference(0.0)//差价参考
                                   .priceFrom(0.0)
                                   .priceTo(0.0)
                                   .priceRange(0.0)
                                   .pricePercent(0.0)
                                   .index(index).bigSeatCount(maxSeats).bigCore(totalPoint)
                                   .modifytime(DateUtil.getFormatDate(new Date(),DatePattren.TIME_FORMAT))
                                   .mark("bigapp积分:"+totalPoint).build();
                                  logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("add_new_policy").message(JSONObject.toJSONString(triptoCustomAddprice)).build());
                                  triptoCustomAddpriceService.insertSelective(triptoCustomAddprice);
                       }else{
                           TriptoCustomAddprice triptoCustomAddprice = triptoCustomAddprices.get(0);
                           if(!ToolUtils.isEmpty(triptoCustomAddprice)){
                               TriptoCustomAddprice updatetriptoCustomAddprice = TriptoCustomAddprice.builder()
                                       .name("system")
                                       .filename("BIG-loop-update积分系统") //文件编号
                                       .platform("ltd/lqe/tuniu/meituan/tongcheng/ali")//
                                       .enable(3)//1 有效 0 无效 3 挂起
                                       .method("AKNEW")
                                       .dptAirport(formCity)
                                       .arrAirport(toCity)
                                       .flyStartday(fromDate)
                                       .flyEndday(fromDate)
                                       .excludeFlyStartday("")
                                       .excludeFlyEndday("")
                                       .flightNoStatus(1)//1，适用 2，排除 3，全部
                                       .flightNo(allFlightNumber)
                                       .isSalePrice(1)//1 固定价格 2 区间价
                                       .salePrice(Double.valueOf(bigCNY.intValue()+config.getAddPrice()))//销售价格
                                       .addPrice(0)//加减钱
                                       .addPricePercent(0.0)//调整百分比
                                       .webrmbPrice(webCNY.doubleValue())//官网人民币总参考价格
                                       .bigrmbPrice(bigCNY.doubleValue())//积分人民币总参考价格
                                       .priceDifference(0.0)//差价参考
                                       .priceFrom(0.0)
                                       .priceTo(0.0)
                                       .priceRange(0.0)
                                       .pricePercent(0.0)
                                       .index(index).bigSeatCount(maxSeats).bigCore(totalPoint)
                                       .modifytime(DateUtil.getFormatDate(new Date(),DatePattren.TIME_FORMAT))
                                       .id(triptoCustomAddprice.getId())
                                       .mark("bigapp积分:"+totalPoint).build();
                                      triptoCustomAddpriceService.updateByPrimaryKeySelective(updatetriptoCustomAddprice);
                           }
                       }
                   }catch (Exception e){
                        log.info(e.getMessage());
                   }


                }
            }
        }
    }

    /**
     * 获取汇率
     * @param currency
     * @return
     */
    private Double getFinalRate(String currency) {
        //做了一个缓存 当天缓存有则用 没有重新拿
        Double exchangeRate = ExchangeRateInstance.getInstance().getExchangeRate(currency);
        if(ToolUtils.isEmpty(exchangeRate)){
            ScExchangeRate scExchangeRate = new ScExchangeRate();
            scExchangeRate.setExchangeCurrency("CNY");
            scExchangeRate.setForeCurrency(currency);
            scExchangeRate.setGroupId("1");
            List<ScExchangeRate> scExchangeRates = scExchangeRateDao.listScExchangeRate(scExchangeRate);
            Double finalRate =null;
            if(!ToolUtils.isEmpty(scExchangeRates)){
                finalRate = scExchangeRates.get(0).getFinalRate();
                ExchangeRateInstance.getInstance().putExchangeRate(currency,finalRate);
            }
            return  finalRate;
        }else{
            return  exchangeRate;
        }
    }


    /**
     * 获取所有航班号 K0123/T7777
     * @param routeInfoEntities
     * @return
     */
    private String getAllFlightNumber(JSONArray routeInfoEntities){
        if (ToolUtils.isEmpty(routeInfoEntities)) {
            return "";
        }
        String flightNumber ="";
        for (int i = 0; i < routeInfoEntities.size(); i++) {
            JSONObject jsonObject = routeInfoEntities.getJSONObject(i);
             flightNumber += jsonObject.getString("flightNumber")+"/";
        }
        return flightNumber.substring(0,flightNumber.lastIndexOf("/"));
    }


    /**
     * 对比行程航班号是否相同
     * @param routeInfoEntities
     * @param web_routeInfoEntities
     * @return
     */
    private boolean compareRouteInfo(JSONArray routeInfoEntities, JSONArray web_routeInfoEntities) {
        if (ToolUtils.isEmpty(routeInfoEntities)
                || ToolUtils.isEmpty(web_routeInfoEntities)) {
            return false;
        }
        //行程站点不对
        if (routeInfoEntities.size() != web_routeInfoEntities.size()) {
            return false;
        }
        //是否所有都相同
        boolean isAllSameAS = true;
        for (int i = 0; i < routeInfoEntities.size(); i++) {
            boolean isExist = false;
            JSONObject jsonObject = routeInfoEntities.getJSONObject(i);
            String flightNumber = jsonObject.getString("flightNumber");
            for (int j = 0; j < web_routeInfoEntities.size(); j++) {
                JSONObject web_jsonObject = web_routeInfoEntities.getJSONObject(j);
                String web_flightNumber = web_jsonObject.containsKey("flightNumber") ? web_jsonObject.getString("flightNumber") : "";
                if (web_flightNumber.equals(flightNumber)) {
                    isExist = true;
                    web_routeInfoEntities.remove(j);
                    break;
                }
            }
            if (!isExist) {
                isAllSameAS = false;
                break;
            }
        }
        return isAllSameAS;
    }

    /**
     * 获取最低套餐的价格
     *
     * @param airlinePriceInfos
     * @return
     */
    private JSONObject getPrice(JSONArray airlinePriceInfos) {
        List<JSONObject> arryList = new ArrayList<>();
        for (int i = 0; i < airlinePriceInfos.size(); i++) {
            JSONObject airlinePriceInfo = airlinePriceInfos.getJSONObject(i);
            if (airlinePriceInfo.getString("cabin").toUpperCase().equals("EC")) {
                JSONObject arrayObjec = new JSONObject();
                BigDecimal adultPrice = airlinePriceInfo.containsKey("adultPrice")
                        ? airlinePriceInfo.getBigDecimal("adultPrice") : new BigDecimal(0);
                BigDecimal adultTax = airlinePriceInfo.containsKey("adultTax")
                        ? airlinePriceInfo.getBigDecimal("adultTax") : new BigDecimal(0);
                //maxSeats
                int maxSeats = airlinePriceInfo.getIntValue("maxSeats");

                JSONObject data =airlinePriceInfo.containsKey("data")?airlinePriceInfo.getJSONObject("data"):new JSONObject();
                if(!ToolUtils.isEmpty(data)){
                    String totalPoint =data.containsKey("AdultQuotedPoints")?data.getString("AdultQuotedPoints"):"-1";
                    arrayObjec.put("AdultQuotedPoints", totalPoint);
                }
                arrayObjec.put("price", adultPrice.add(adultTax));
                arrayObjec.put("maxSeats", maxSeats);
                arryList.add(arrayObjec);
            }
        }
        if (ToolUtils.isEmpty(arryList)) {
            return new JSONObject();
        } else {
            Collections.sort(arryList, new Comparator<JSONObject>() {
                @Override
                public int compare(JSONObject o1, JSONObject o2) {
                    return o1.getBigDecimal("price").multiply(new BigDecimal(1000))
                                .subtract(o2.getBigDecimal("price").multiply(new BigDecimal(1000))).intValue();
                }
            });
            return arryList.get(0);
        }
    }


    /**
     * @param airSource
     * @param fromStation
     * @param toStation
     * @param fromDate
     * @param currency
     * @param retDate
     * @return
     */
    public String searchData(String airSource, String fromStation, String toStation, String fromDate, String currency, String retDate) {

        JSONObject reqJSON = new JSONObject();
        reqJSON.put("adultNum", config.getPeronNum());
        reqJSON.put("airSource", airSource);
        reqJSON.put("childNum", "0");
        reqJSON.put("formCity", fromStation);
        reqJSON.put("toCity", toStation);
        reqJSON.put("fromDate", fromDate);
        reqJSON.put("currency", currency);
        reqJSON.put("retDate", "");
        //单程票还是回程票
        reqJSON.put("tripType", "1");
        logger.info(SysLogger.builder().logFilePath("searchlog").isCreateFile(true).name("searchlog").message("查询参数--->"+reqJSON.toString()).build());
        if (airSource.equals(SourceEnum.AK_WEB.getSourceName())) {
            return OkHttpDownLoader.textBody(config.getSearchUrl()).json(reqJSON.toString()).okhttpexecute().asString();
        } else {
            return OkHttpDownLoader.textBody(config.getBigSearchUrl()).json(reqJSON.toString()).okhttpexecute().asString();
        }
    }


}
