package com.bjlt.spider.service.impl;

import com.alibaba.druid.support.json.JSONUtils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.dao.ScPolicyDao;
import com.bjlt.spider.entity.*;
import com.bjlt.spider.service.ScPolicyService;
import com.bjlt.spider.service.SmallAirLineService;
import com.bjlt.spider.service.TriptoCustomAddpriceService;
import com.bjlt.spider.utils.LoopCommonUtils;
import com.luyn.core.StringUtil;
import com.luyn.date.DatePattren;
import com.luyn.date.DateUtil;
import com.luyn.http.okhttp.OkHttpDownLoader;
import com.luyn.json.JsonUtils;
import com.luyn.log.SysLogger;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.*;

/**
 * @author: luyanan0718@163.com
 * @create :2018/4/11 10:24
 * @introduce :
 **/
@Service
@Slf4j
public class SmallAirLineServiceImpl implements SmallAirLineService {
	private static final SysLogger logger = SysLogger.getSysLogger(SmallAirLineServiceImpl.class);

	@Autowired
	Config config;

	@Autowired
	ScPolicyDao scPolicyDao;

	@Autowired
	LoopCommonUtils loopCommonUtils;

	@Autowired
	ScPolicyService scPolicyService;


	@Autowired
	TriptoCustomAddpriceService triptoCustomAddpriceService;

	@Override
	public void worker(ScPolicy scPolicy) {
		// 监控
		Map<String, Object> monitor = new HashMap<>();

		monitor.put("startDate", new Date());
		monitor.put("request", scPolicy);


		// 先根据请求参数查询big信息

		boolean flg = false;
		String dateStart = scPolicy.getFromDateStart();


		if (StringUtil.isNotBlank(dateStart)) {
			// 根据出发城市获取币种
			String currency = config.getCityCurrency().get(scPolicy.getFromCity());


			Double reteDo = loopCommonUtils.getFinalRate(currency);

			//没查到汇率   不执行
			if (reteDo == null || reteDo <= 0) {
				return;

			}
           // 根据币种获取汇率
			BigDecimal rate = new BigDecimal(reteDo);


			// 根据条件查询现有政策信息
			List<ScPolicy> oldScpolicys = scPolicyDao.listScPolicy(scPolicy);
			log.info("查询出来的现有的政策为-->{}", JSON.toJSONString(oldScpolicys));


			//积分查询出来的信息
			String bigContent = loopCommonUtils.searchData(SourceEnum.AK_BIG_APP.getSourceName(), scPolicy.getFromCity(), scPolicy.getToCity(), scPolicy.getFromDateStart(), currency, "", config);

			/**
			 * 判断   新的积分跟原来积分是否有变化
			 *     无变化，则不处理
			 // 比较积分 ，如果不变，则不管  如果变了，比较优势
			 // 如果变大  继续比较    如果变小 则不管
			 */


			if (oldScpolicys != null && oldScpolicys.size() > 0) {

				if (StringUtil.isNotBlank(bigContent)) {
					String attachment = JsonUtils.get(bigContent, "attachment");
					// 反解析为实体类
					if (StringUtil.isNotBlank(attachment)) {
						SearchResponseEntity searchResponseEntity = JSON.toJavaObject(JSONObject.parseObject(attachment), SearchResponseEntity.class);

						if (searchResponseEntity.getFromSegments() != null && searchResponseEntity.getFromSegments().size() > 0) {

							for (AirlineInfomation fromSegment : searchResponseEntity.getFromSegments()) {
								for (ScPolicy oldScpolicy : oldScpolicys) {

									//先匹配航班号
									boolean isCompareRouteInfoEntities = compareRouteInfoEntities(oldScpolicy.getFlightNumberLimit(), fromSegment.getRouteInfoEntities());
									if (isCompareRouteInfoEntities) {

										//  航班匹配的 进行积分对比处理
										AirlinePriceInfo cheapAirlinePrice = cheapestPrice(fromSegment.getAirlinePriceInfos());
										// 比较积分 ，如果不变，则不管  如果变了，比较优势
										// 如果变大  继续比较    如果变小 则不管


										// 新的积分
										BigDecimal adultQuotedPoints = new BigDecimal(cheapAirlinePrice.getData().get("AdultQuotedPoints").toString());
										BigDecimal oldAdultQuotedPoints = null;
										String bigScore = oldScpolicy.getBigScore();
										if(StringUtil.isNotBlank(bigScore)){
											 oldAdultQuotedPoints = new BigDecimal(bigScore);
										}else {
											 oldAdultQuotedPoints = new BigDecimal(0);
										}
										monitor.put("adultQuotedPoints", adultQuotedPoints.doubleValue());
										monitor.put("oldAdultQuotedPoints", oldAdultQuotedPoints.doubleValue());

										if (adultQuotedPoints.compareTo(oldAdultQuotedPoints) > 0) {
											log.info("{}积分有优势,旧的积分为-->{}，新的积分为-->{}", JSON.toJSONString(oldScpolicy), oldAdultQuotedPoints.doubleValue(), adultQuotedPoints.doubleValue());
//										// 查询官网价格
//										String webContent = loopCommonUtils.searchData(SourceEnum.AK_WEB.getSourceName(), scPolicy.getFromCity(), scPolicy.getToCity(), scPolicy.getFromDateStart(), currency, "", config);
//										String webAttachment = JsonUtils.get(bigContent, "attachment");

											flg = true;

//										// 转换币种进行比较
//										BigDecimal rate = new BigDecimal(loopCommonUtils.getFinalRate(currency));
//
//
//										// 如果新的积分比原来的积分大，则重新比较

											monitor.put("iscompare", true);


										} else {
											log.info("积分无优势,旧的积分为-->{}，新的积分为-->{}，查询参数为-->{}", oldAdultQuotedPoints.doubleValue(), adultQuotedPoints.doubleValue(), JSON.toJSONString(oldScpolicy));
											monitor.put("iscompare", false);
										}


									}
								}

							}


						}


						System.out.println("searchResponseEntity" + JSON.toJSONString(searchResponseEntity));
						// 当flg为true的时候  说明需要进行对比
						if (flg) {
							log.info("需要进行对比-->{}", JSON.toJSONString(scPolicy));
							String webContent = loopCommonUtils.searchData(SourceEnum.AK_WEB.getSourceName(), scPolicy.getFromCity(), scPolicy.getToCity(), scPolicy.getFromDateStart(), currency, "", config);
							String webAttachment = JsonUtils.get(webContent, "attachment");

							// web 端的返回
							SearchResponseEntity webSearchResponseEntity = JSON.toJavaObject(JSONObject.parseObject(webAttachment), SearchResponseEntity.class);


							List<Map<String, Object>> compare = compare(searchResponseEntity.getFromSegments(), webSearchResponseEntity.getFromSegments(), rate);
							monitor.put("bigAttachment", attachment);
							monitor.put("webAttachment", webAttachment);
							monitor.put("conpare", compare);

						}

						monitor.put("endDate", new Date());
						config.getMonitor().add(monitor);
					}


				} else {
					monitor.put("error", "获取big数据失败");
				}


			}

		}


	}


	/**
	 * 进行行程的对比
	 *
	 * @param bigAirlineInfomations
	 * @param webAirlineInfomations
	 */
	public List<Map<String, Object>> compare(List<AirlineInfomation> bigAirlineInfomations, List<AirlineInfomation> webAirlineInfomations, BigDecimal rate) {
		List<Map<String, Object>> monitors = new ArrayList<>();
		if (bigAirlineInfomations != null && bigAirlineInfomations.size() > 0 && webAirlineInfomations != null && webAirlineInfomations.size() > 0) {

			bigAirlineInfomations.stream().forEach(bigAirlineInfomation -> {

				//取出航班号
				StringBuffer flightNumbers = new StringBuffer();
				bigAirlineInfomation.getRouteInfoEntities().stream().forEach(routeInfoEntity -> {

					flightNumbers.append(routeInfoEntity.getFlightNumber()).append("/");

				});
				flightNumbers.deleteCharAt(flightNumbers.length() - 1);


				System.out.println("航班号为--->{}" + flightNumbers.toString());
				AirlinePriceInfo bigPrice = cheapestPrice(bigAirlineInfomation.getAirlinePriceInfos());
				// 取出成人价格
				BigDecimal bigAdultPrice = bigPrice.getAdultPrice().add(bigPrice.getAdultTax());
				// 兑换为人民币

				BigDecimal bigAdultPrice_cny = bigAdultPrice.multiply(rate);


				webAirlineInfomations.stream().forEach(webAirlineInfomation -> {
					Map<String, Object> monitor = new HashMap<>();
					//将big 的航班跟亚航的进行对比 然后取出最低价格
					boolean flg = compareRouteInfoEntities(flightNumbers.toString(), webAirlineInfomation.getRouteInfoEntities());
					if (flg) {

						// 获取最低价格
						AirlinePriceInfo webPrice = cheapestPrice(webAirlineInfomation.getAirlinePriceInfos());
						//进行币种的兑换
						// web的价格


						BigDecimal webAdultPrice = webPrice.getAdultPrice().add(webPrice.getAdultTax());
						BigDecimal webAdultPrice_cny = webAdultPrice.multiply(rate);
						// 进行判断
						log.info("big的价钱为-->{}，web端的价格为-->{}", bigAdultPrice_cny.doubleValue(), webAdultPrice_cny.doubleValue());
						monitor.put("bigPrice", bigAdultPrice_cny.doubleValue());
						monitor.put("webPrice", webAdultPrice_cny.doubleValue());
						monitor.put("flightNumbers", flightNumbers);
						if ((webAdultPrice_cny.subtract(bigAdultPrice_cny).doubleValue()) >= config.getBig_web_price()) {

							//进行入库
							log.info("需要进行修改政策");
							monitor.put("status", "修改政策");
							update(bigAirlineInfomation.getFormCity(), bigAirlineInfomation.getToCity(), bigAirlineInfomation.getFromDate(), flightNumbers.toString(), webAdultPrice_cny, bigAdultPrice_cny, bigPrice.getData().get("AdultQuotedPoints").toString(), config,bigPrice.getMaxSeats(), scPolicyService, triptoCustomAddpriceService);


						} else {
							//修改状态为失效
							log.info("需要进行修改状态为失效");
							monitor.put("status", "设置失效");
							updateStatus(bigAirlineInfomation.getFormCity(), bigAirlineInfomation.getToCity(), bigAirlineInfomation.getFromDate(), flightNumbers.toString(), webAdultPrice_cny, bigAdultPrice_cny, bigPrice.getData().get("AdultQuotedPoints").toString(), config,bigPrice.getMaxSeats(), scPolicyService, triptoCustomAddpriceService);
						}
						monitors.add(monitor);
					}


				});


			});


		}

		return monitors;

	}


	/**
	 * 计算出最便宜的成人价格  积分数量
	 *
	 * @param airlinePriceInfos
	 * @return
	 */
	public static AirlinePriceInfo cheapestPrice(List<AirlinePriceInfo> airlinePriceInfos) {
		List<BigDecimal> prices = new ArrayList<>();
		airlinePriceInfos.stream().forEach(airlinePriceInfo -> {
			if (airlinePriceInfo.getCabin().equals("EC")) {
				prices.add(airlinePriceInfo.getAdultPrice());
			}
		});


		// 对价格进行排序

		if (prices != null && prices.size() > 0) {
			Collections.sort(prices);
			// 根据价格获取到具体的价格信息
			BigDecimal minPrce = prices.get(0);

			for (AirlinePriceInfo airlinePriceInfo : airlinePriceInfos) {
				if (airlinePriceInfo.getCabin().equals("EC")) {
					if (minPrce.compareTo(airlinePriceInfo.getAdultPrice()) == 0) {

						return airlinePriceInfo;

					}
				}
			}


		}
		return null;

	}

	/***
	 * 进行航班的匹配
	 * @param flightNumbers
	 * @param routeInfoEntities
	 * @return
	 */
	public boolean compareRouteInfoEntities(String flightNumbers, List<RouteInfoEntity> routeInfoEntities) {
//		String oldFlight = scPolicy.getFlightNumberLimit();


		boolean flg = false;

		List<Boolean> booleans = new ArrayList<>();
		if (routeInfoEntities != null && routeInfoEntities.size() > 0) {
			for (RouteInfoEntity routeInfoEntity : routeInfoEntities) {

				if (flightNumbers.contains(routeInfoEntity.getFlightNumber())) {
					booleans.add(true);

				} else {
					booleans.add(false);
				}
			}


		}

		if (booleans.contains(false)) {
			flg = false;
		} else {
			flg = true;
		}


		return flg;

	}


	/**
	 * 政策更新
	 *
	 * @param formCity
	 * @param toCity
	 * @param fromDate
	 * @param allFlightNumber
	 * @param webCNY
	 * @param bigCNY
	 * @param totalPoint
	 * @param config
	 * @param scPolicyService
	 * @param  maxSears  座位数
	 */
	public void update(String formCity, String toCity, String fromDate, String allFlightNumber, BigDecimal webCNY, BigDecimal bigCNY, String totalPoint, Config config,Integer maxSears, ScPolicyService scPolicyService, TriptoCustomAddpriceService triptoCustomAddpriceService) {


		try {
			ScPolicy scPolicy = new ScPolicy();
			scPolicy.setAirSourceGroupId(1);
			scPolicy.setCid("QUNA");
			scPolicy.setFromCity(formCity);
			scPolicy.setToCity(toCity);
			scPolicy.setFromDateStart(fromDate);
			scPolicy.setFromDateEnd(fromDate);
			scPolicy.setFlightNumberLimit(allFlightNumber);

			List<ScPolicy> scPolicies = scPolicyService.listScPolicy(scPolicy);
			System.out.println("scPolicies---" + scPolicies.size());
			if (scPolicies != null && scPolicies.size() > 0) {
				Integer id = scPolicies.get(0).getId();
				scPolicy.setId(id);
				scPolicy.setFlightNumberLimitType(1);



				scPolicy.setLowPrice(new BigDecimal(10));
				scPolicy.setUpPrice(new BigDecimal(99999999));
				scPolicy.setAdjustType("0");

				scPolicy.setStatus(3);
				scPolicy.setAddOrSubtractMoney("0");
				scPolicy.setAddTime(DateUtil.getFormatDate(new Date(), DatePattren.TIME_FORMAT));
				scPolicy.setScore(String.valueOf(bigCNY.doubleValue()));
				scPolicy.setFileNo("积分自维");
				scPolicy.setOriginalPrice(webCNY);
				scPolicy.setPolicySource("point");
				scPolicy.setCabinScope("0");
				scPolicy.setFinalPrice(new BigDecimal(bigCNY.intValue() + config.getAddPrice()));
				scPolicy.setBigScore(totalPoint);
				scPolicy.setBigSeatCount(maxSears);
				logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("add_old_policy").message(JSONObject.toJSONString(scPolicy)).build());
				scPolicyService.updateByPrimaryKeySelective(scPolicy);
				log.info("新政策表开始更新，更新参数为-->{}", JSON.toJSONString(scPolicy));
			}


		} catch (Exception e) {
			e.printStackTrace();
		}

		try {
			//插入新的政策表
			TriptoCustomAddprice triptoCustomAddprice = new TriptoCustomAddprice();

			triptoCustomAddprice.setDptAirport(formCity);
			triptoCustomAddprice.setArrAirport(toCity);
			triptoCustomAddprice.setFlyStartday(fromDate);
			triptoCustomAddprice.setFlyEndday(fromDate);
			triptoCustomAddprice.setFlightNo(allFlightNumber);

			List<TriptoCustomAddprice> triptoCustomAddprices = triptoCustomAddpriceService.listPageTriptoCustomAddprice(triptoCustomAddprice);

          log.info("旧政策表查询到的条数--》{}，参数为-=->{}",triptoCustomAddprices.size(),JSON.toJSONString(triptoCustomAddprice));
			if (triptoCustomAddprices != null && triptoCustomAddprices.size() > 0) {

				Integer id = triptoCustomAddprices.get(0).getId();
//				triptoCustomAddprice.setName("system");
//				triptoCustomAddprice.setPlatform("ltd/lqe/tuniu/meituan/tongcheng/ali");//
//				triptoCustomAddprice.setMethod("AKNEW");
				System.out.println("triptoCustomAddpricesId ---"+triptoCustomAddprices);
				triptoCustomAddprice.setEnable(3);//1 有;效 0 无效 3 挂起
				triptoCustomAddprice.setExcludeFlyStartday("");
				triptoCustomAddprice.setExcludeFlyEndday("");
				triptoCustomAddprice.setFlightNoStatus(2);//1，适用 2，排除 3，全部

				triptoCustomAddprice.setIsSalePrice(1);//1 固定价格 2 区间价
				triptoCustomAddprice.setAddPrice(0);//加减钱
				triptoCustomAddprice.setAddPricePercent(0.0);//调整百分比
				triptoCustomAddprice.setPriceDifference(0.0);//差价参考
				triptoCustomAddprice.setPriceFrom(0.0);
				triptoCustomAddprice.setPriceTo(0.0);
				triptoCustomAddprice.setPriceRange(0.0);
				triptoCustomAddprice.setPricePercent(0.0);
				triptoCustomAddprice.setId(id);
				triptoCustomAddprice.setSalePrice(Double.valueOf(bigCNY.intValue() + config.getAddPrice()));//销售价格
				triptoCustomAddprice.setFilename("积分自维"); //文件编号
				triptoCustomAddprice.setWebrmbPrice(webCNY.doubleValue());//官网人民币总参考价格
				triptoCustomAddprice.setBigrmbPrice(bigCNY.doubleValue());//积分人民币总参考价格
				triptoCustomAddprice.setBigSeatCount(maxSears);
				triptoCustomAddprice.setModifytime(DateUtil.getFormatDate(new Date(), DatePattren.TIME_FORMAT));
				triptoCustomAddprice.setMark("bigapp积分:" + totalPoint);
				logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("add_new_policy").message(JSONObject.toJSONString(triptoCustomAddprice)).build());
				triptoCustomAddpriceService.updateByPrimaryKeySelective(triptoCustomAddprice);
				log.info("旧政策表开始更新，更新参数为-->{}", JSON.toJSONString(triptoCustomAddprice));
			}


		} catch (Exception e) {
			log.info(e.getMessage());
		}


	}


	/**
	 * 修改状态
	 */
	public void updateStatus(String formCity, String toCity, String fromDate, String allFlightNumber, BigDecimal webCNY, BigDecimal bigCNY, String totalPoint, Config config,Integer maxSears,ScPolicyService scPolicyService, TriptoCustomAddpriceService triptoCustomAddpriceService) {
		try {
			ScPolicy scPolicy = new ScPolicy();
			scPolicy.setAirSourceGroupId(1);
			scPolicy.setCid("QUNA");
			scPolicy.setFromCity(formCity);
			scPolicy.setToCity(toCity);
			scPolicy.setFromDateStart(fromDate);
			scPolicy.setFromDateEnd(fromDate);
			scPolicy.setFlightNumberLimit(allFlightNumber);
			List<ScPolicy> scPolicies = scPolicyService.listScPolicy(scPolicy);
			if (scPolicies != null && scPolicies.size() > 0) {
				Integer id = scPolicies.get(0).getId();
				scPolicy.setId(id);
				scPolicy.setFileNo("积分自维");
				scPolicy.setStatus(0);
				scPolicy.setAddTime(DateUtil.getFormatDate(new Date(), DatePattren.TIME_FORMAT));
				scPolicy.setScore(String.valueOf(bigCNY.doubleValue()));
				scPolicy.setFileNo("积分自维");
				scPolicy.setOriginalPrice(webCNY);
				scPolicy.setPolicySource("point");
				scPolicy.setCabinScope("0");
				scPolicy.setFinalPrice(new BigDecimal(bigCNY.intValue() + config.getAddPrice()));
				scPolicy.setBigScore(totalPoint);
				scPolicy.setBigSeatCount(maxSears);
				logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("add_old_policy").message(JSONObject.toJSONString(scPolicy)).build());
				scPolicyService.updateByPrimaryKeySelective(scPolicy);
				log.info("新政策表状态开始更新，更新参数为-->{}", JSON.toJSONString(scPolicy));

			}


		} catch (Exception e) {
			e.printStackTrace();
		}
		try {
			//插入新的政策表
			TriptoCustomAddprice triptoCustomAddprice = new TriptoCustomAddprice();

			triptoCustomAddprice.setDptAirport(formCity);
			triptoCustomAddprice.setArrAirport(toCity);
			triptoCustomAddprice.setFlyStartday(fromDate);
			triptoCustomAddprice.setFlyEndday(fromDate);
			triptoCustomAddprice.setFlightNo(allFlightNumber);

			List<TriptoCustomAddprice> triptoCustomAddprices = triptoCustomAddpriceService.listPageTriptoCustomAddprice(triptoCustomAddprice);
			if (triptoCustomAddprices != null && triptoCustomAddprices.size() > 0) {
				Integer id = triptoCustomAddprices.get(0).getId();
				triptoCustomAddprice.setId(id);
				triptoCustomAddprice.setEnable(0);//1 有;效 0 无效 3 挂起
				triptoCustomAddprice.setName("system");
				triptoCustomAddprice.setPlatform("ltd/lqe/tuniu/meituan/tongcheng/ali");//
				triptoCustomAddprice.setMethod("AKNEW");
				triptoCustomAddprice.setSalePrice(Double.valueOf(bigCNY.intValue() + config.getAddPrice()));//销售价格
				triptoCustomAddprice.setFilename("积分自维"); //文件编号
				triptoCustomAddprice.setWebrmbPrice(webCNY.doubleValue());//官网人民币总参考价格
				triptoCustomAddprice.setBigrmbPrice(bigCNY.doubleValue());//积分人民币总参考价格
				triptoCustomAddprice.setBigSeatCount(maxSears);
				triptoCustomAddprice.setModifytime(DateUtil.getFormatDate(new Date(), DatePattren.TIME_FORMAT));
				triptoCustomAddprice.setMark("bigapp积分:" + totalPoint);
				logger.info(SysLogger.builder().logFilePath("log").isCreateFile(true).name("add_new_policy").message(JSONObject.toJSONString(triptoCustomAddprice)).build());
				triptoCustomAddpriceService.updateByPrimaryKeySelective(triptoCustomAddprice);

			}
		} catch (Exception e) {
			log.info(e.getMessage());
		}

	}

}
